TmkRecognizedEvent class

Inheritance
Annotations

Constructors

TmkRecognizedEvent({required String? sessionId, required String sdkSessionId, required String sourceLangCode, required String targetLangCode, required bool isFinal, required Map<String, Object?> extraData, String? text, String? channel})
const
TmkRecognizedEvent.fromMap(Map<Object?, Object?> map)
factory

Properties

channel → String?
finalinherited
extraData → Map<String, Object?>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isFinal → bool
finalinherited
kind → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkSessionId → String
finalinherited
sessionId → String?
finalinherited
sourceLangCode → String
finalinherited
targetLangCode → String
finalinherited
text → String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited