TmkRuntimeStatus class

Annotations

Constructors

TmkRuntimeStatus({required TmkEngineStatus onlineEngineStatus, required TmkEngineStatus offlineEngineStatus, required TmkAuthInfo authInfo, required String versionText})
const
TmkRuntimeStatus.fromMap(Map<Object?, Object?> map)
factory

Properties

authInfo → TmkAuthInfo
final
hashCode → int
The hash code for this object.
no setterinherited
offlineEngineStatus → TmkEngineStatus
final
onlineEngineStatus → TmkEngineStatus
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionText → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited