TmkTranslationMode enum

Inheritance
Available extensions

Values

online → const TmkTranslationMode
const TmkTranslationMode('online')
offline → const TmkTranslationMode
const TmkTranslationMode('offline')
auto → const TmkTranslationMode
const TmkTranslationMode('auto')
mix → const TmkTranslationMode
const TmkTranslationMode('mix')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromValue(String value) → TmkTranslationMode

Constants

values → const List<TmkTranslationMode>
A constant List of the values in this enum, in order of their declaration.